@@ -22,12 +22,14 @@ def write_output_npy(data):
 
 
 def detect_type_from_suffix(filepath):
-    KNOWN_SUFFIXES = {'.mlmodel': 'coreml',
+    KNOWN_SUFFIXES = {'.caffemodel': 'caffe',
+                      '.mlmodel': 'coreml',
                       '.onnx': 'onnx',
                       '.pb': 'tensorflow',
                       '.prototxt': 'caffe',
                       '.pth': 'pytorch',
-                      '.tflite': 'tensorflowlite'}
+                      '.tflite': 'tensorflowlite',
+                      '.xml': 'openvino'}
 
     for suffix in KNOWN_SUFFIXES:
         if suffix in filepath.suffixes:
